Enum TruncSide

enum TruncSide

Type which used for defining truncation side in the VariableOutputCore trait.

Variants

Left

Truncate left side, i.e. &out[..n].

Right

Truncate right side, i.e. &out[m..].

Implementations

impl Clone for TruncSide

fn clone(self: &Self) -> TruncSide

impl Copy for TruncSide

impl Debug for TruncSide

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Freeze for TruncSide

impl RefUnwindSafe for TruncSide

impl Send for TruncSide

impl Sync for TruncSide

impl Unpin for TruncSide

impl UnsafeUnpin for TruncSide

impl UnwindSafe for TruncSide

impl<T> Any for TruncSide

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for TruncSide

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for TruncSide

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for TruncSide

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for TruncSide

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> Same for TruncSide

impl<T> ToOwned for TruncSide

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T, U> Into for TruncSide

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for TruncSide

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for TruncSide

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>