Trait CoreProxy
trait CoreProxy: sealed::Sealed
A proxy trait to a core type implemented by CoreWrapper
Associated Types
type CoreType wrapped by
CoreWrapper.
Implementors
impl<T> CoreProxy for CoreWrapper<T>
CoreProxytrait CoreProxy: sealed::Sealed
A proxy trait to a core type implemented by CoreWrapper
type CoreType wrapped by CoreWrapper.
impl<T> CoreProxy for CoreWrapper<T>