FixedOutputCore

Trait FixedOutputCore 

pub trait FixedOutputCore:
    UpdateCore
    + BufferKindUser
    + OutputSizeUser
where Self::BlockSize: IsLess<U256>, Le<Self::BlockSize, U256>: NonZero,
{ // Required method fn finalize_fixed_core( &mut self, buffer: &mut Buffer<Self>, out: &mut Output<Self>, ); }
Core trait for hash functions with fixed output size.

Required Methods

fn finalize_fixed_core( &mut self, buffer: &mut Buffer<Self>, out: &mut Output<Self>, )

Finalize state using remaining data stored in the provided block buffer, write result into provided array and leave self in a dirty state.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<T, OutSize, O> FixedOutputCore for CtVariableCoreWrapper<T, OutSize, O>
where T: VariableOutputCore, OutSize: ArrayLength<u8> + IsLessOrEqual<T::OutputSize> + 'static, LeEq<OutSize, T::OutputSize>: NonZero, T::BlockSize: IsLess<U256>, Le<T::BlockSize, U256>: NonZero,