Macro impl_oid_carrier
macro_rules! impl_oid_carrier {
($name:ident, $oid:literal) => { ... };
}
Implement dummy type with hidden docs which is used to "carry" hasher
OID for CtVariableCoreWrapper.
impl_oid_carriermacro_rules! impl_oid_carrier {
($name:ident, $oid:literal) => { ... };
}
Implement dummy type with hidden docs which is used to "carry" hasher
OID for CtVariableCoreWrapper.