SmallBlockSizeUser

Trait SmallBlockSizeUser 

pub trait SmallBlockSizeUser: BlockSizeUser<BlockSize = Self::_BlockSize> {
    type _BlockSize: BlockSizes;
}
Sub-trait of BlockSizeUser implemented if BlockSize is bigger than U0 and smaller than U256.

This trait relies on the hack suggested here to work around the long standing Rust issue regarding non-propagation of where bounds.

Required Associated Types

type _BlockSize: BlockSizes

Helper associated type equal to <Self as BlockSizeUser>::BlockSize.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors