Trait FixedOutputCore

trait FixedOutputCore: UpdateCore + BufferKindUser + OutputSizeUser
where
    <Self as >::BlockSize: IsLess<crypto_common::typenum::U256>,
    crypto_common::typenum::Le<<Self as >::BlockSize, crypto_common::typenum::U256>: NonZero

Core trait for hash functions with fixed output size.

Required Methods

fn finalize_fixed_core(self: &mut Self, buffer: &mut Buffer<Self>, out: &mut Output<Self>)

Finalize state using remaining data stored in the provided block buffer, write result into provided array and leave self in a dirty state.

Implementors