[−][src]Trait digest::ExtendableOutput
Trait which describes extendable-output functions (XOF).
Associated Types
Loading content...Required methods
pub fn finalize_xof(self) -> Self::Reader where
Self: Sized, [src]
Self: Sized,
Retrieve XOF reader and consume hasher instance.
pub fn finalize_xof_reset(&mut self) -> Self::Reader[src]
Retrieve XOF reader and reset hasher instance state.
Provided methods
pub fn finalize_boxed(self, n: usize) -> Box<[u8]> where
Self: Sized, [src]
Self: Sized,
This is supported on crate feature
alloc only.Retrieve result into a boxed slice of the specified size and consume the hasher.
Box<[u8]> is used instead of Vec<u8> to save stack space, since
they have size of 2 and 3 words respectively.
pub fn finalize_boxed_reset(&mut self, n: usize) -> Box<[u8]>[src]
This is supported on crate feature
alloc only.Retrieve result into a boxed slice of the specified size and reset the hasher's state.
Box<[u8]> is used instead of Vec<u8> to save stack space, since
they have size of 2 and 3 words respectively.