Trait ExtendableOutputReset

trait ExtendableOutputReset: ExtendableOutput + Reset

Trait for hash functions with extendable-output (XOF) able to reset themselves.

Required Methods

fn finalize_xof_reset(self: &mut Self) -> <Self as >::Reader

Retrieve XOF reader and reset hasher instance state.

Provided Methods

fn finalize_xof_reset_into(self: &mut Self, out: &mut [u8])

Finalize XOF, write result into out, and reset the hasher state.

fn finalize_boxed_reset(self: &mut Self, output_size: usize) -> Box<[u8]>

Retrieve result into a boxed slice of the specified size and reset the hasher state.

Box<[u8]> is used instead of Vec<u8> to save stack space, since they have size of 2 and 3 words respectively.

Implementors