Trait VariableOutputReset
trait VariableOutputReset: VariableOutput + Reset
Trait for hash functions with variable-size output able to reset themselves.
Required Methods
fn finalize_variable_reset(self: &mut Self, out: &mut [u8]) -> Result<(), InvalidBufferSize>Write result into the output buffer and reset the hasher state.
Returns
Err(InvalidOutputSize)ifoutsize is not equal toself.output_size().
Provided Methods
fn finalize_boxed_reset(self: &mut Self) -> Box<[u8]>Retrieve result into a boxed slice and reset the hasher state.
Box<[u8]>is used instead ofVec<u8>to save stack space, since they have size of 2 and 3 words respectively.
Implementors
impl<T> VariableOutputReset for RtVariableCoreWrapper<T>